@@ -128,6 +128,23 @@ get.gof <- function(models) {
 override <- function(models, override.coef, override.se, override.pval, 
     override.ci.low, override.ci.up) {
   
+  if (class(override.se) == "list" || length(override.se) > 1 || 
+      override.se[1] != 0) {
+    if (length(override.pval) == 1 && class(override.pval) != "list" && 
+        override.pval[1] == 0) {
+      warning(paste("Standard errors were provided using 'override.se',", 
+          "but p-values were not replaced!"))
+    }
+  }
+  if (class(override.pval) == "list" || length(override.pval) > 1 || 
+      override.pval[1] != 0) {
+    if (length(override.se) == 1 && class(override.se) != "list" && 
+        override.se[1] == 0) {
+      warning(paste("P-values were provided using 'override.pval',", 
+          "but standard errors were not replaced!"))
+    }
+  }
+  
   for (i in 1:length(models)) {
     
     # coefficients
@@ -513,6 +530,9 @@ modelnames <- function(model.list, tr.objects, model.names) {
   mnames <- names(model.list)
   if (is.null(mnames)) {
     mnames <- character(length(model.list))
+    if (length(mnames) != length(tr.objects)) {
+      mnames <- character(length(tr.objects))
+    }
   }
   
   for (i in 1:length(tr.objects)) {
@@ -523,7 +543,7 @@ modelnames <- function(model.list, tr.objects, model.names) {
   }
   
   if (is.null(model.names)) {
-    model.names <- rep(NA, length(model.list))
+    model.names <- rep(NA, length(mnames))
   } else if (class(model.names) != "character") {
     stop("Model names must be specified as a vector of strings.")
   } else if (length(model.names) != length(tr.objects)) {
@@ -567,6 +587,9 @@ stars.string <- function(pval, stars, star.char, star.prefix, star.suffix,
   if (length(unique(st)) != length(st)) {
     stop("Duplicate elements are not allowed in the stars argument.")
   }
+  if (is.na(pval)) {
+    pval <- 1.0
+  }
   if (length(st) > 4) {
     stop("A maximum of four values is allowed in the stars argument.")
   } else if (length(st) > 2 && pval < st[1]) {  # three stars
@@ -622,7 +645,10 @@ outputmatrix <- function(m, single.row, neginfstring, leading.zero, digits,
             se.prefix.current <- gsub("\\(", "[", se.prefix.current)
             se.suffix.current <- gsub("\\)", "]", se.suffix.current)
           }
-          
+          if (is.na(m[i, j + 1])) {
+            se.prefix.current <- ""
+            se.suffix.current <- ""
+          }
           if (ci[k - 1] == FALSE) {
             std <- paste(se.prefix.current, coeftostring(m[i, j + 1], 
                 leading.zero, digits = digits), se.suffix.current, sep = "")
@@ -650,7 +676,10 @@ outputmatrix <- function(m, single.row, neginfstring, leading.zero, digits,
           } else {
             dollar <- "$"
           }
-          if (ci[k - 1] == FALSE && m[i, j + 2] < bold) { #significant pvalue
+          if (is.na(m[i, j + 2])) {
+            m[i, j + 2] <- 1.0
+          }
+          if (ci[k - 1] == FALSE && m[i, j + 2] < bold) { # significant p-value
             bold.pref <- bold.prefix
             bold.suff <- bold.suffix
           } else if (ci[k - 1] == TRUE && bold > 0 &&  # significant CI
@@ -687,10 +716,10 @@ outputmatrix <- function(m, single.row, neginfstring, leading.zero, digits,
       while (j <= length(m)) {
         if (is.na(m[i, j]) || is.nan(m[i, j])) {
           output.matrix[(i * 2) - 1, k] <- ""  #upper coefficient row
-          output.matrix[(i * 2), k] <- ""  #lower std row
+          output.matrix[(i * 2), k] <- ""  #lower se row
         } else if (m[i, j] == -Inf) {
           output.matrix[(i * 2) - 1, k] <- neginfstring  #upper row
-          output.matrix[(i * 2), k] <- ""  #lower std row
+          output.matrix[(i * 2), k] <- ""  #lower se row
         } else {
           
           # in case of CIs, replace brackets by square brackets
@@ -700,7 +729,10 @@ outputmatrix <- function(m, single.row, neginfstring, leading.zero, digits,
             se.prefix.current <- "["
             se.suffix.current <- "]"
           }
-          
+          if (is.na(m[i, j + 1])) {
+            se.prefix.current <- ""
+            se.suffix.current <- ""
+          }
           if (ci[k - 1] == FALSE) {
             p <- stars.string(m[i, j + 2], stars, star.char, star.prefix, 
               star.suffix, symbol)
@@ -718,7 +750,10 @@ outputmatrix <- function(m, single.row, neginfstring, leading.zero, digits,
           } else {
             dollar <- "$"
           }
-          if (ci[k - 1] == FALSE && m[i, j + 2] < bold) { #significant pvalue
+          if (is.na(m[i, j + 2])) {
+            m[i, j + 2] <- 1.0
+          }
+          if (ci[k - 1] == FALSE && m[i, j + 2] < bold) { # significant p-value
             bold.pref <- bold.prefix
             bold.suff <- bold.suffix
           } else if (ci[k - 1] == TRUE && bold > 0 &&  # significant CI
